@@ -66,9 +66,20 @@ redactor_from_packages <- function(packages) {
 find_package_functions <- function(packages, file = "redact.R") {
   # Given package names, find any redactors put in inst/httptest/redact.R
   base_pkgs <- c(
-    "base", "compiler", "datasets", "graphics", "grDevices",
-    "grid", "methods", "parallel", "splines", "stats", "stats4",
-    "tcltk", "tools", "utils"
+    "base",
+    "compiler",
+    "datasets",
+    "graphics",
+    "grDevices",
+    "grid",
+    "methods",
+    "parallel",
+    "splines",
+    "stats",
+    "stats4",
+    "tcltk",
+    "tools",
+    "utils"
   )
   packages <- setdiff(packages, base_pkgs)
   funcs <- lapply(packages, get_package_function, file)
@@ -121,8 +132,9 @@ get_current_redactor <- function() {
       # We're using the result of default_redactor(). Let's see if any
       # new packages have been loaded
       current_packages <- get_attached_packages()
+      packages_changed <- !identical(current_packages, pkgs)
       # Also, always reevaluate the default redactor if pkgload is involved
-      if ("pkgload" %in% loadedNamespaces() || !identical(current_packages, pkgs)) {
+      if (packages_changed || "pkgload" %in% loadedNamespaces()) {
         # Re-evaluate
         out <- default_redactor(current_packages)
         options(httptest2.redactor = out)
